@@ -11,11 +11,10 @@
 #include <errno.h>
 #include <limits.h>
 #include "R.h"
-#include "Rdefines.h"
+#include "Rinternals.h"
+#include "Rversion.h"
 #include "R_ext/Rdynload.h"
 #include "R_ext/Parse.h"
-#include "R_ext/Print.h"
-#include "R_ext/PrtUtil.h"
 #include "yaml.h"
 
 #define REAL_BUF_SIZE 256
@@ -42,6 +41,6 @@ SEXP Ryaml_serialize_to_yaml(SEXP s_obj, SEXP s_line_sep, SEXP s_indent, SEXP s_
 
 SEXP Ryaml_unserialize_from_yaml(SEXP s_string, SEXP s_as_named_list,
     SEXP s_handlers, SEXP s_error_label, SEXP s_eval_expr,
-    SEXP s_eval_warning);
+    SEXP s_eval_warning, SEXP s_merge_precedence, SEXP s_merge_warning);
 
 #endif
